@@ -21,11 +21,11 @@ import unittest
 from django.test import TestCase
 
 from postorius.forms.list_forms import (
-    ListSubscribe, ChangeSubscriptionForm, ListNew, ListIdentityForm,
-    ListMassSubscription, ListMassRemoval, ListAddBanForm, ListHeaderMatchForm,
-    MemberModeration, ListAutomaticResponsesForm, DMARCMitigationsForm,
-    DigestSettingsForm, MessageAcceptanceForm, ArchiveSettingsForm,
-    ListAnonymousSubscribe, ListSubscriptionPolicyForm)
+    ArchiveSettingsForm, ChangeSubscriptionForm, DigestSettingsForm,
+    DMARCMitigationsForm, ListAddBanForm, ListAnonymousSubscribe,
+    ListAutomaticResponsesForm, ListHeaderMatchForm, ListIdentityForm,
+    ListMassRemoval, ListMassSubscription, ListNew, ListSubscribe,
+    ListSubscriptionPolicyForm, MemberModeration, MessageAcceptanceForm)
 from postorius.tests.utils import create_mock_list
 
 
@@ -235,6 +235,8 @@ class TestListIdentityForm(TestCase):
             'info': 'This is a larger description of this mailing list.',
             'display_name': 'Most Desirable Mailing List',
             'subject_prefix': '  [Most Desirable]               ',
+            'preferred_language': 'en',
+            'member_roster_visibility': 'public',
         }, mlist=None)
         self.assertFalse(form.is_valid())
         self.assertTrue('advertised' in form.errors)
@@ -423,7 +425,14 @@ class TestDigestSettingsForm(TestCase):
         self.assertTrue(form.is_valid())
 
     def test_all_fields(self):
-        pass
+        formdata = dict(
+            digests_enabled='True',
+            digests_send_periodic='True',
+            digests_volume_frequency='daily',
+            digest_size_threshold='10',
+        )
+        form = DigestSettingsForm(formdata, mlist=None)
+        self.assertTrue(form.is_valid())
 
 
 class TestMessageAcceptanceForm(TestCase):
